package fr.u_psud.keller.td9;

import android.app.FragmentManager;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.hardware.Camera;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

public class AdvancedPhotoActivity extends AppCompatActivity {

    // Appareil photo et zone de prévisualisation
    private Camera webcam;
    private Previsualisation zonePrev;

    // Gestionnaire de fragments et instance de nos deux fragments
    FragmentManager fragmentManager;
    PrevFragment prevFragment = new PrevFragment();
    PhotoFragment photoFragment = new PhotoFragment();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_advanced_photo);

        // On initialise le gestionnaire de fragment
        fragmentManager = getFragmentManager();

        // On attache le fragment de prévisualisation
        fragmentManager.beginTransaction().add(R.id.prev_ou_photo, prevFragment).commit();
    }

    @Override
    protected void onResume() {
        super.onResume();

        // On initialise la caméra
        try {
            webcam = Camera.open(1);
        }
        catch (Exception e){
            e.printStackTrace();
        }

        // On lance la prévisualisation
        zonePrev = new Previsualisation(this, webcam);
        prevFragment.relancerPrev(zonePrev);
    }

    @Override
    protected void onPause() {
        // On laisse la possibilité aux autres applications d'utiliser la caméra
        if (webcam != null){
            webcam.release();
            webcam = null;
        }
        super.onPause();
    }

    // Évènement associé à la prise d'une photo
    private Camera.PictureCallback prisePhoto = new Camera.PictureCallback() {
        @Override
        public void onPictureTaken(byte[] photo, Camera camera) {
            // Lorsque la photo est prise, on l'affiche dans le fragment prévu à cet effet
            Bitmap bitmap = BitmapFactory.decodeByteArray(photo, 0, photo.length);
            photoFragment.afficherPhoto(bitmap);
        }
    };

    // Méthode appelée lorsqu'on appuie sur le bouton "Cheese!"
    public void cheese(View view) {
        prevFragment.arreterPrev();
        // On change le fragment attaché
        if (!photoFragment.isAdded())
            fragmentManager.beginTransaction().replace(R.id.prev_ou_photo, photoFragment).commit();
        // On prend la photo
        webcam.takePicture(null, null, prisePhoto);
    }

    // Méthode appelée lorsqu'on appuie sur le bouton "Retour"
    public void retour(View view) {
        // On change le fragment attaché
        if (!prevFragment.isAdded())
            fragmentManager.beginTransaction().replace(R.id.prev_ou_photo, prevFragment).commit();
        // On relance la prévisualisation
        zonePrev = new Previsualisation(this, webcam);
        prevFragment.relancerPrev(zonePrev);
    }
}
