package fr.u_psud.keller.td9;

import android.content.Context;
import android.hardware.Camera;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import java.io.IOException;


public class Previsualisation extends SurfaceView implements SurfaceHolder.Callback {
    private Camera webcam;
    private SurfaceHolder evenement;

    // Constructeur
    public Previsualisation(Context context, Camera webcam) {
        // On appelle le constructeur de la super-classe sur le contexte
        super(context);
        // On stocke la webcam passée en argument dans un champ de la classe
        this.webcam = webcam;

        // Le SurfaceHolder permet de réagir lorsque la prévisualisation est créée ou détruite
        evenement = getHolder();
        evenement.addCallback(this);
    }

    // Cette méthode est appelée lorsque la SurfaceView est créée
    public void surfaceCreated(SurfaceHolder holder) {
        // Lorsque la surface est créée, on affiche la prévisualisation
        try {
            webcam.setPreviewDisplay(holder);
            webcam.startPreview();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    // Cette méthode est appelée lorsque la surface est détruite
    public void surfaceDestroyed(SurfaceHolder holder) {
        // Rien à faire : c'est l'activité qui s'occupe d'arrêter la webcam
    }

    // Cette méthode est appelée lorsque la surface est modifiée, par exemple en cas de rotation
    // de la tablette
    public void surfaceChanged(SurfaceHolder holder, int format, int w, int h) {
        // On arrête la prévisualisation
        try {
            webcam.stopPreview();
        } catch (Exception e){
            e.printStackTrace();
        }

        // On relance la prévisualisation avec la nouvelle surface
        try {
            webcam.setPreviewDisplay(holder);
            webcam.startPreview();

        } catch (Exception e){
            e.printStackTrace();
        }
    }
}